The django-refinery package was written by `Jacob Radford`_ and
based on the `django-filter <https://github.com/alex/django-filter>`_
project by `Alex Gaynor <https://github.com/alex>`_.

django-refinery Project Leads
-----------------------------

* `Jacob Radford <https://github.com/nkryptic>`_

django-refinery Contributors
----------------------------

For the current list of code contributors to the django-refinery project,
visit http://github.com/nkryptic/django-refinery/contributors

Additional concepts were integrated from:

* `django-qfilters <https://github.com/subsume/django-qfilters>`_ 
  project by `Steve Yeago <https://github.com/subsume>`_
* `Alisue <https://github.com/lambdaalisue>`_
* `Stephan Jaekel <https://github.com/stephrdev>`_
* `Marke Wywial <https://github.com/onjin>`_ via 
  `I-DOTCOM LLC <https://github.com/i-dotcom>`_
* `Vladislav Poluhin <https://github.com/midiotthimble>`_
* `Ross Poulton <https://github.com/rossp>`_
* `Sergiy Kuzmenko <https://github.com/shelldweller>`_
* `Tino de Bruijn <https://github.com/tino>`_
* `Richard Barran <https://github.com/richardbarran>`_
* `Maurizio Melani <https://github.com/gislab>`_

django-filter Project Founder
-----------------------------

* `Alex Gaynor <https://github.com/alex>`_

django-filter Contributors
--------------------------

* `Ben Firshman <https://github.com/bfirsh>`_
* `Jannis Leidel <https://github.com/jezdez>`_
* `Martin Mahner <https://github.com/bartTC>`_
* `Brian Rosner <https://github.com/brosner>`_
* `Adam Vandenberg <https://github.com/adamv>`_
* `Tino de Bruijn <https://github.com/tino>`_
* `Vladimir Sidorenko <https://github.com/gearheart>`_
* `Maximillian Dornseif <https://github.com/mdornseif>`_
* `Marc Fargas <https://github.com/telenieko>`_

